@@ -230,7 +230,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
     namespace_name: str = None
     description: str = None
     change_password_if_take_over: bool = None
-    different_user_id_for_login_and_data_retention: bool = None
     create_account_script: ScriptSetting = None
     authentication_script: ScriptSetting = None
     create_take_over_script: ScriptSetting = None
@@ -249,10 +248,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.change_password_if_take_over = change_password_if_take_over
         return self
 
-    def with_different_user_id_for_login_and_data_retention(self, different_user_id_for_login_and_data_retention: bool) -> UpdateNamespaceRequest:
-        self.different_user_id_for_login_and_data_retention = different_user_id_for_login_and_data_retention
-        return self
-
     def with_create_account_script(self, create_account_script: ScriptSetting) -> UpdateNamespaceRequest:
         self.create_account_script = create_account_script
         return self
@@ -295,7 +290,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
             .with_namespace_name(data.get('namespaceName'))\
             .with_description(data.get('description'))\
             .with_change_password_if_take_over(data.get('changePasswordIfTakeOver'))\
-            .with_different_user_id_for_login_and_data_retention(data.get('differentUserIdForLoginAndDataRetention'))\
             .with_create_account_script(ScriptSetting.from_dict(data.get('createAccountScript')))\
             .with_authentication_script(ScriptSetting.from_dict(data.get('authenticationScript')))\
             .with_create_take_over_script(ScriptSetting.from_dict(data.get('createTakeOverScript')))\
@@ -307,7 +301,6 @@ class UpdateNamespaceRequest(core.Gs2Request):
             "namespaceName": self.namespace_name,
             "description": self.description,
             "changePasswordIfTakeOver": self.change_password_if_take_over,
-            "differentUserIdForLoginAndDataRetention": self.different_user_id_for_login_and_data_retention,
             "createAccountScript": self.create_account_script.to_dict() if self.create_account_script else None,
             "authenticationScript": self.authentication_script.to_dict() if self.authentication_script else None,
             "createTakeOverScript": self.create_take_over_script.to_dict() if self.create_take_over_script else None,
@@ -596,6 +589,7 @@ class DeleteAccountRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     user_id: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteAccountRequest:
         self.namespace_name = namespace_name
@@ -605,6 +599,10 @@ class DeleteAccountRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteAccountRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -641,6 +639,7 @@ class AuthenticationRequest(core.Gs2Request):
     user_id: str = None
     key_id: str = None
     password: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> AuthenticationRequest:
         self.namespace_name = namespace_name
@@ -658,6 +657,10 @@ class AuthenticationRequest(core.Gs2Request):
         self.password = password
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> AuthenticationRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1403,6 +1406,7 @@ class DeleteDataOwnerByUserIdRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     user_id: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteDataOwnerByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1412,6 +1416,10 @@ class DeleteDataOwnerByUserIdRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteDataOwnerByUserIdRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
