@@ -425,7 +425,7 @@ class CreateRoomRequest(core.Gs2Request):
     metadata: str = None
     password: str = None
     white_list_user_ids: List[str] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateRoomRequest:
         self.namespace_name = namespace_name
@@ -451,6 +451,10 @@ class CreateRoomRequest(core.Gs2Request):
         self.white_list_user_ids = white_list_user_ids
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> CreateRoomRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -503,6 +507,7 @@ class CreateRoomFromBackendRequest(core.Gs2Request):
     metadata: str = None
     password: str = None
     white_list_user_ids: List[str] = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateRoomFromBackendRequest:
         self.namespace_name = namespace_name
@@ -528,6 +533,10 @@ class CreateRoomFromBackendRequest(core.Gs2Request):
         self.white_list_user_ids = white_list_user_ids
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> CreateRoomFromBackendRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -623,7 +632,7 @@ class UpdateRoomRequest(core.Gs2Request):
     password: str = None
     white_list_user_ids: List[str] = None
     access_token: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateRoomRequest:
         self.namespace_name = namespace_name
@@ -649,6 +658,10 @@ class UpdateRoomRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> UpdateRoomRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -701,6 +714,7 @@ class UpdateRoomFromBackendRequest(core.Gs2Request):
     password: str = None
     white_list_user_ids: List[str] = None
     user_id: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateRoomFromBackendRequest:
         self.namespace_name = namespace_name
@@ -726,6 +740,10 @@ class UpdateRoomFromBackendRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> UpdateRoomFromBackendRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -775,7 +793,7 @@ class DeleteRoomRequest(core.Gs2Request):
     namespace_name: str = None
     room_name: str = None
     access_token: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteRoomRequest:
         self.namespace_name = namespace_name
@@ -789,6 +807,10 @@ class DeleteRoomRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteRoomRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -826,6 +848,7 @@ class DeleteRoomFromBackendRequest(core.Gs2Request):
     namespace_name: str = None
     room_name: str = None
     user_id: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteRoomFromBackendRequest:
         self.namespace_name = namespace_name
@@ -839,6 +862,10 @@ class DeleteRoomFromBackendRequest(core.Gs2Request):
         self.user_id = user_id
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteRoomFromBackendRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -879,7 +906,6 @@ class DescribeMessagesRequest(core.Gs2Request):
     access_token: str = None
     start_at: int = None
     limit: int = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeMessagesRequest:
         self.namespace_name = namespace_name
@@ -1022,7 +1048,7 @@ class PostRequest(core.Gs2Request):
     category: int = None
     metadata: str = None
     password: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PostRequest:
         self.namespace_name = namespace_name
@@ -1048,6 +1074,10 @@ class PostRequest(core.Gs2Request):
         self.password = password
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PostRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1169,7 +1199,6 @@ class GetMessageRequest(core.Gs2Request):
     message_name: str = None
     password: str = None
     access_token: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetMessageRequest:
         self.namespace_name = namespace_name
@@ -1297,6 +1326,7 @@ class DeleteMessageRequest(core.Gs2Request):
     room_name: str = None
     user_id: str = None
     message_name: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteMessageRequest:
         self.namespace_name = namespace_name
@@ -1314,6 +1344,10 @@ class DeleteMessageRequest(core.Gs2Request):
         self.message_name = message_name
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteMessageRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1354,7 +1388,6 @@ class DescribeSubscribesRequest(core.Gs2Request):
     access_token: str = None
     page_token: str = None
     limit: int = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeSubscribesRequest:
         self.namespace_name = namespace_name
@@ -1526,7 +1559,7 @@ class SubscribeRequest(core.Gs2Request):
     room_name: str = None
     access_token: str = None
     notification_types: List[NotificationType] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> SubscribeRequest:
         self.namespace_name = namespace_name
@@ -1544,6 +1577,10 @@ class SubscribeRequest(core.Gs2Request):
         self.notification_types = notification_types
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> SubscribeRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1657,7 +1694,6 @@ class GetSubscribeRequest(core.Gs2Request):
     namespace_name: str = None
     room_name: str = None
     access_token: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetSubscribeRequest:
         self.namespace_name = namespace_name
@@ -1759,7 +1795,7 @@ class UpdateNotificationTypeRequest(core.Gs2Request):
     room_name: str = None
     access_token: str = None
     notification_types: List[NotificationType] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateNotificationTypeRequest:
         self.namespace_name = namespace_name
@@ -1777,6 +1813,10 @@ class UpdateNotificationTypeRequest(core.Gs2Request):
         self.notification_types = notification_types
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> UpdateNotificationTypeRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1890,7 +1930,7 @@ class UnsubscribeRequest(core.Gs2Request):
     namespace_name: str = None
     room_name: str = None
     access_token: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UnsubscribeRequest:
         self.namespace_name = namespace_name
@@ -1904,6 +1944,10 @@ class UnsubscribeRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> UnsubscribeRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
