@@ -290,7 +290,6 @@ class DescribeDataObjectsRequest(core.Gs2Request):
     status: str = None
     page_token: str = None
     limit: int = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeDataObjectsRequest:
         self.namespace_name = namespace_name
@@ -421,7 +420,7 @@ class PrepareUploadRequest(core.Gs2Request):
     scope: str = None
     allow_user_ids: List[str] = None
     update_if_exists: bool = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareUploadRequest:
         self.namespace_name = namespace_name
@@ -451,6 +450,10 @@ class PrepareUploadRequest(core.Gs2Request):
         self.update_if_exists = update_if_exists
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PrepareUploadRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -593,7 +596,7 @@ class UpdateDataObjectRequest(core.Gs2Request):
     access_token: str = None
     scope: str = None
     allow_user_ids: List[str] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateDataObjectRequest:
         self.namespace_name = namespace_name
@@ -615,6 +618,10 @@ class UpdateDataObjectRequest(core.Gs2Request):
         self.allow_user_ids = allow_user_ids
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> UpdateDataObjectRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -738,7 +745,7 @@ class PrepareReUploadRequest(core.Gs2Request):
     data_object_name: str = None
     access_token: str = None
     content_type: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareReUploadRequest:
         self.namespace_name = namespace_name
@@ -756,6 +763,10 @@ class PrepareReUploadRequest(core.Gs2Request):
         self.content_type = content_type
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PrepareReUploadRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -857,7 +868,7 @@ class DoneUploadRequest(core.Gs2Request):
     namespace_name: str = None
     data_object_name: str = None
     access_token: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DoneUploadRequest:
         self.namespace_name = namespace_name
@@ -871,6 +882,10 @@ class DoneUploadRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DoneUploadRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -963,7 +978,7 @@ class DeleteDataObjectRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     data_object_name: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DeleteDataObjectRequest:
         self.namespace_name = namespace_name
@@ -977,6 +992,10 @@ class DeleteDataObjectRequest(core.Gs2Request):
         self.data_object_name = data_object_name
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DeleteDataObjectRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1069,7 +1088,7 @@ class PrepareDownloadRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     data_object_id: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadRequest:
         self.namespace_name = namespace_name
@@ -1083,6 +1102,10 @@ class PrepareDownloadRequest(core.Gs2Request):
         self.data_object_id = data_object_id
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1176,7 +1199,7 @@ class PrepareDownloadByGenerationRequest(core.Gs2Request):
     access_token: str = None
     data_object_id: str = None
     generation: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadByGenerationRequest:
         self.namespace_name = namespace_name
@@ -1194,6 +1217,10 @@ class PrepareDownloadByGenerationRequest(core.Gs2Request):
         self.generation = generation
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadByGenerationRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1295,7 +1322,7 @@ class PrepareDownloadOwnDataRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     data_object_name: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadOwnDataRequest:
         self.namespace_name = namespace_name
@@ -1309,6 +1336,10 @@ class PrepareDownloadOwnDataRequest(core.Gs2Request):
         self.data_object_name = data_object_name
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadOwnDataRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1402,7 +1433,7 @@ class PrepareDownloadOwnDataByGenerationRequest(core.Gs2Request):
     access_token: str = None
     data_object_name: str = None
     generation: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PrepareDownloadOwnDataByGenerationRequest:
         self.namespace_name = namespace_name
@@ -1420,6 +1451,10 @@ class PrepareDownloadOwnDataByGenerationRequest(core.Gs2Request):
         self.generation = generation
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PrepareDownloadOwnDataByGenerationRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1566,7 +1601,6 @@ class DescribeDataObjectHistoriesRequest(core.Gs2Request):
     data_object_name: str = None
     page_token: str = None
     limit: int = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeDataObjectHistoriesRequest:
         self.namespace_name = namespace_name
@@ -1694,7 +1728,6 @@ class GetDataObjectHistoryRequest(core.Gs2Request):
     access_token: str = None
     data_object_name: str = None
     generation: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetDataObjectHistoryRequest:
         self.namespace_name = namespace_name
