@@ -1247,457 +1247,6 @@ class Gs2LotteryRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
-    def _describe_boxes(
-        self,
-        request: DescribeBoxesRequest,
-        callback: Callable[[AsyncResult[DescribeBoxesResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lottery',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/me/box".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-        if request.page_token is not None:
-            query_strings["pageToken"] = request.page_token
-        if request.limit is not None:
-            query_strings["limit"] = request.limit
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.access_token:
-            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
-        _job = rest.NetworkJob(
-            url=url,
-            method='GET',
-            result_type=DescribeBoxesResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def describe_boxes(
-        self,
-        request: DescribeBoxesRequest,
-    ) -> DescribeBoxesResult:
-        async_result = []
-        with timeout(30):
-            self._describe_boxes(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def describe_boxes_async(
-        self,
-        request: DescribeBoxesRequest,
-    ) -> DescribeBoxesResult:
-        async_result = []
-        self._describe_boxes(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _describe_boxes_by_user_id(
-        self,
-        request: DescribeBoxesByUserIdRequest,
-        callback: Callable[[AsyncResult[DescribeBoxesByUserIdResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lottery',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/{userId}/box".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-        if request.page_token is not None:
-            query_strings["pageToken"] = request.page_token
-        if request.limit is not None:
-            query_strings["limit"] = request.limit
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        _job = rest.NetworkJob(
-            url=url,
-            method='GET',
-            result_type=DescribeBoxesByUserIdResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def describe_boxes_by_user_id(
-        self,
-        request: DescribeBoxesByUserIdRequest,
-    ) -> DescribeBoxesByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._describe_boxes_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def describe_boxes_by_user_id_async(
-        self,
-        request: DescribeBoxesByUserIdRequest,
-    ) -> DescribeBoxesByUserIdResult:
-        async_result = []
-        self._describe_boxes_by_user_id(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _get_box(
-        self,
-        request: GetBoxRequest,
-        callback: Callable[[AsyncResult[GetBoxResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lottery',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/me/box/{prizeTableName}".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.access_token:
-            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
-        _job = rest.NetworkJob(
-            url=url,
-            method='GET',
-            result_type=GetBoxResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def get_box(
-        self,
-        request: GetBoxRequest,
-    ) -> GetBoxResult:
-        async_result = []
-        with timeout(30):
-            self._get_box(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def get_box_async(
-        self,
-        request: GetBoxRequest,
-    ) -> GetBoxResult:
-        async_result = []
-        self._get_box(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _get_box_by_user_id(
-        self,
-        request: GetBoxByUserIdRequest,
-        callback: Callable[[AsyncResult[GetBoxByUserIdResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lottery',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/{userId}/box/{prizeTableName}".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
-            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        _job = rest.NetworkJob(
-            url=url,
-            method='GET',
-            result_type=GetBoxByUserIdResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def get_box_by_user_id(
-        self,
-        request: GetBoxByUserIdRequest,
-    ) -> GetBoxByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._get_box_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def get_box_by_user_id_async(
-        self,
-        request: GetBoxByUserIdRequest,
-    ) -> GetBoxByUserIdResult:
-        async_result = []
-        self._get_box_by_user_id(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _reset_box(
-        self,
-        request: ResetBoxRequest,
-        callback: Callable[[AsyncResult[ResetBoxResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lottery',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/me/box/{prizeTableName}".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.access_token:
-            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
-        _job = rest.NetworkJob(
-            url=url,
-            method='DELETE',
-            result_type=ResetBoxResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def reset_box(
-        self,
-        request: ResetBoxRequest,
-    ) -> ResetBoxResult:
-        async_result = []
-        with timeout(30):
-            self._reset_box(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def reset_box_async(
-        self,
-        request: ResetBoxRequest,
-    ) -> ResetBoxResult:
-        async_result = []
-        self._reset_box(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-    def _reset_box_by_user_id(
-        self,
-        request: ResetBoxByUserIdRequest,
-        callback: Callable[[AsyncResult[ResetBoxByUserIdResult]], None],
-        is_blocking: bool,
-    ):
-        url = Gs2Constant.ENDPOINT_HOST.format(
-            service='lottery',
-            region=self.session.region,
-        ) + "/{namespaceName}/user/{userId}/box/{prizeTableName}".format(
-            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
-            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
-            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
-        )
-
-        headers = self._create_authorized_headers()
-        query_strings = {
-            'contextStack': request.context_stack,
-        }
-
-        if request.request_id:
-            headers["X-GS2-REQUEST-ID"] = request.request_id
-        if request.duplication_avoider:
-            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
-        _job = rest.NetworkJob(
-            url=url,
-            method='DELETE',
-            result_type=ResetBoxByUserIdResult,
-            callback=callback,
-            headers=headers,
-            query_strings=query_strings,
-        )
-
-        self.session.send(
-            job=_job,
-            is_blocking=is_blocking,
-        )
-
-    def reset_box_by_user_id(
-        self,
-        request: ResetBoxByUserIdRequest,
-    ) -> ResetBoxByUserIdResult:
-        async_result = []
-        with timeout(30):
-            self._reset_box_by_user_id(
-                request,
-                lambda result: async_result.append(result),
-                is_blocking=True,
-            )
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
-
-    async def reset_box_by_user_id_async(
-        self,
-        request: ResetBoxByUserIdRequest,
-    ) -> ResetBoxByUserIdResult:
-        async_result = []
-        self._reset_box_by_user_id(
-            request,
-            lambda result: async_result.append(result),
-            is_blocking=False,
-        )
-
-        import asyncio
-        with timeout(30):
-            while not async_result:
-                await asyncio.sleep(0.01)
-
-        if async_result[0].error:
-            raise async_result[0].error
-        return async_result[0].result
-
     def _describe_lottery_models(
         self,
         request: DescribeLotteryModelsRequest,
@@ -2066,6 +1615,249 @@ class Gs2LotteryRestClient(rest.AbstractGs2RestClient):
             raise async_result[0].error
         return async_result[0].result
 
+    def _prediction(
+        self,
+        request: PredictionRequest,
+        callback: Callable[[AsyncResult[PredictionResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/me/lottery/{lotteryName}/prediction".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            lotteryName=request.lottery_name if request.lottery_name is not None and request.lottery_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.random_seed is not None:
+            body["randomSeed"] = request.random_seed
+        if request.count is not None:
+            body["count"] = request.count
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.access_token:
+            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=PredictionResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def prediction(
+        self,
+        request: PredictionRequest,
+    ) -> PredictionResult:
+        async_result = []
+        with timeout(30):
+            self._prediction(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def prediction_async(
+        self,
+        request: PredictionRequest,
+    ) -> PredictionResult:
+        async_result = []
+        self._prediction(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _prediction_by_user_id(
+        self,
+        request: PredictionByUserIdRequest,
+        callback: Callable[[AsyncResult[PredictionByUserIdResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/{userId}/lottery/{lotteryName}/prediction".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            lotteryName=request.lottery_name if request.lottery_name is not None and request.lottery_name != '' else 'null',
+            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.random_seed is not None:
+            body["randomSeed"] = request.random_seed
+        if request.count is not None:
+            body["count"] = request.count
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=PredictionByUserIdResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def prediction_by_user_id(
+        self,
+        request: PredictionByUserIdRequest,
+    ) -> PredictionByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._prediction_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def prediction_by_user_id_async(
+        self,
+        request: PredictionByUserIdRequest,
+    ) -> PredictionByUserIdResult:
+        async_result = []
+        self._prediction_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _draw_with_random_seed_by_user_id(
+        self,
+        request: DrawWithRandomSeedByUserIdRequest,
+        callback: Callable[[AsyncResult[DrawWithRandomSeedByUserIdResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/{userId}/lottery/{lotteryName}/draw/withSeed".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            lotteryName=request.lottery_name if request.lottery_name is not None and request.lottery_name != '' else 'null',
+            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        body = {
+            'contextStack': request.context_stack,
+        }
+        if request.random_seed is not None:
+            body["randomSeed"] = request.random_seed
+        if request.count is not None:
+            body["count"] = request.count
+        if request.config is not None:
+            body["config"] = [
+                item.to_dict()
+                for item in request.config
+            ]
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        _job = rest.NetworkJob(
+            url=url,
+            method='POST',
+            result_type=DrawWithRandomSeedByUserIdResult,
+            callback=callback,
+            headers=headers,
+            body=body,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def draw_with_random_seed_by_user_id(
+        self,
+        request: DrawWithRandomSeedByUserIdRequest,
+    ) -> DrawWithRandomSeedByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._draw_with_random_seed_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def draw_with_random_seed_by_user_id_async(
+        self,
+        request: DrawWithRandomSeedByUserIdRequest,
+    ) -> DrawWithRandomSeedByUserIdResult:
+        async_result = []
+        self._draw_with_random_seed_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
     def _draw_by_stamp_sheet(
         self,
         request: DrawByStampSheetRequest,
@@ -2787,6 +2579,457 @@ class Gs2LotteryRestClient(rest.AbstractGs2RestClient):
             is_blocking=False,
         )
 
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _describe_boxes(
+        self,
+        request: DescribeBoxesRequest,
+        callback: Callable[[AsyncResult[DescribeBoxesResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/me/box".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+        if request.page_token is not None:
+            query_strings["pageToken"] = request.page_token
+        if request.limit is not None:
+            query_strings["limit"] = request.limit
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.access_token:
+            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=DescribeBoxesResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def describe_boxes(
+        self,
+        request: DescribeBoxesRequest,
+    ) -> DescribeBoxesResult:
+        async_result = []
+        with timeout(30):
+            self._describe_boxes(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def describe_boxes_async(
+        self,
+        request: DescribeBoxesRequest,
+    ) -> DescribeBoxesResult:
+        async_result = []
+        self._describe_boxes(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _describe_boxes_by_user_id(
+        self,
+        request: DescribeBoxesByUserIdRequest,
+        callback: Callable[[AsyncResult[DescribeBoxesByUserIdResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/{userId}/box".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+        if request.page_token is not None:
+            query_strings["pageToken"] = request.page_token
+        if request.limit is not None:
+            query_strings["limit"] = request.limit
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=DescribeBoxesByUserIdResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def describe_boxes_by_user_id(
+        self,
+        request: DescribeBoxesByUserIdRequest,
+    ) -> DescribeBoxesByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._describe_boxes_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def describe_boxes_by_user_id_async(
+        self,
+        request: DescribeBoxesByUserIdRequest,
+    ) -> DescribeBoxesByUserIdResult:
+        async_result = []
+        self._describe_boxes_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _get_box(
+        self,
+        request: GetBoxRequest,
+        callback: Callable[[AsyncResult[GetBoxResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/me/box/{prizeTableName}".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.access_token:
+            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetBoxResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_box(
+        self,
+        request: GetBoxRequest,
+    ) -> GetBoxResult:
+        async_result = []
+        with timeout(30):
+            self._get_box(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_box_async(
+        self,
+        request: GetBoxRequest,
+    ) -> GetBoxResult:
+        async_result = []
+        self._get_box(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _get_box_by_user_id(
+        self,
+        request: GetBoxByUserIdRequest,
+        callback: Callable[[AsyncResult[GetBoxByUserIdResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/{userId}/box/{prizeTableName}".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
+            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        _job = rest.NetworkJob(
+            url=url,
+            method='GET',
+            result_type=GetBoxByUserIdResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def get_box_by_user_id(
+        self,
+        request: GetBoxByUserIdRequest,
+    ) -> GetBoxByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._get_box_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def get_box_by_user_id_async(
+        self,
+        request: GetBoxByUserIdRequest,
+    ) -> GetBoxByUserIdResult:
+        async_result = []
+        self._get_box_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _reset_box(
+        self,
+        request: ResetBoxRequest,
+        callback: Callable[[AsyncResult[ResetBoxResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/me/box/{prizeTableName}".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.access_token:
+            headers["X-GS2-ACCESS-TOKEN"] = request.access_token
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        _job = rest.NetworkJob(
+            url=url,
+            method='DELETE',
+            result_type=ResetBoxResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def reset_box(
+        self,
+        request: ResetBoxRequest,
+    ) -> ResetBoxResult:
+        async_result = []
+        with timeout(30):
+            self._reset_box(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def reset_box_async(
+        self,
+        request: ResetBoxRequest,
+    ) -> ResetBoxResult:
+        async_result = []
+        self._reset_box(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
+        import asyncio
+        with timeout(30):
+            while not async_result:
+                await asyncio.sleep(0.01)
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+    def _reset_box_by_user_id(
+        self,
+        request: ResetBoxByUserIdRequest,
+        callback: Callable[[AsyncResult[ResetBoxByUserIdResult]], None],
+        is_blocking: bool,
+    ):
+        url = Gs2Constant.ENDPOINT_HOST.format(
+            service='lottery',
+            region=self.session.region,
+        ) + "/{namespaceName}/user/{userId}/box/{prizeTableName}".format(
+            namespaceName=request.namespace_name if request.namespace_name is not None and request.namespace_name != '' else 'null',
+            prizeTableName=request.prize_table_name if request.prize_table_name is not None and request.prize_table_name != '' else 'null',
+            userId=request.user_id if request.user_id is not None and request.user_id != '' else 'null',
+        )
+
+        headers = self._create_authorized_headers()
+        query_strings = {
+            'contextStack': request.context_stack,
+        }
+
+        if request.request_id:
+            headers["X-GS2-REQUEST-ID"] = request.request_id
+        if request.duplication_avoider:
+            headers["X-GS2-DUPLICATION-AVOIDER"] = request.duplication_avoider
+        _job = rest.NetworkJob(
+            url=url,
+            method='DELETE',
+            result_type=ResetBoxByUserIdResult,
+            callback=callback,
+            headers=headers,
+            query_strings=query_strings,
+        )
+
+        self.session.send(
+            job=_job,
+            is_blocking=is_blocking,
+        )
+
+    def reset_box_by_user_id(
+        self,
+        request: ResetBoxByUserIdRequest,
+    ) -> ResetBoxByUserIdResult:
+        async_result = []
+        with timeout(30):
+            self._reset_box_by_user_id(
+                request,
+                lambda result: async_result.append(result),
+                is_blocking=True,
+            )
+
+        if async_result[0].error:
+            raise async_result[0].error
+        return async_result[0].result
+
+
+    async def reset_box_by_user_id_async(
+        self,
+        request: ResetBoxByUserIdRequest,
+    ) -> ResetBoxByUserIdResult:
+        async_result = []
+        self._reset_box_by_user_id(
+            request,
+            lambda result: async_result.append(result),
+            is_blocking=False,
+        )
+
         import asyncio
         with timeout(30):
             while not async_result:
