@@ -1053,6 +1053,7 @@ class RatingModel(core.Gs2Model):
     rating_model_id: str = None
     name: str = None
     metadata: str = None
+    initial_value: int = None
     volatility: int = None
 
     def with_rating_model_id(self, rating_model_id: str) -> RatingModel:
@@ -1067,6 +1068,10 @@ class RatingModel(core.Gs2Model):
         self.metadata = metadata
         return self
 
+    def with_initial_value(self, initial_value: int) -> RatingModel:
+        self.initial_value = initial_value
+        return self
+
     def with_volatility(self, volatility: int) -> RatingModel:
         self.volatility = volatility
         return self
@@ -1148,6 +1153,7 @@ class RatingModel(core.Gs2Model):
             .with_rating_model_id(data.get('ratingModelId'))\
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
+            .with_initial_value(data.get('initialValue'))\
             .with_volatility(data.get('volatility'))
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1155,6 +1161,7 @@ class RatingModel(core.Gs2Model):
             "ratingModelId": self.rating_model_id,
             "name": self.name,
             "metadata": self.metadata,
+            "initialValue": self.initial_value,
             "volatility": self.volatility,
         }
 
@@ -1164,6 +1171,7 @@ class RatingModelMaster(core.Gs2Model):
     name: str = None
     metadata: str = None
     description: str = None
+    initial_value: int = None
     volatility: int = None
     created_at: int = None
     updated_at: int = None
@@ -1184,6 +1192,10 @@ class RatingModelMaster(core.Gs2Model):
         self.description = description
         return self
 
+    def with_initial_value(self, initial_value: int) -> RatingModelMaster:
+        self.initial_value = initial_value
+        return self
+
     def with_volatility(self, volatility: int) -> RatingModelMaster:
         self.volatility = volatility
         return self
@@ -1274,6 +1286,7 @@ class RatingModelMaster(core.Gs2Model):
             .with_name(data.get('name'))\
             .with_metadata(data.get('metadata'))\
             .with_description(data.get('description'))\
+            .with_initial_value(data.get('initialValue'))\
             .with_volatility(data.get('volatility'))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))
@@ -1284,6 +1297,7 @@ class RatingModelMaster(core.Gs2Model):
             "name": self.name,
             "metadata": self.metadata,
             "description": self.description,
+            "initialValue": self.initial_value,
             "volatility": self.volatility,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
@@ -1468,6 +1482,7 @@ class Namespace(core.Gs2Model):
     join_notification: NotificationSetting = None
     leave_notification: NotificationSetting = None
     complete_notification: NotificationSetting = None
+    change_rating_notification: NotificationSetting = None
     log_setting: LogSetting = None
     created_at: int = None
     updated_at: int = None
@@ -1528,6 +1543,10 @@ class Namespace(core.Gs2Model):
         self.complete_notification = complete_notification
         return self
 
+    def with_change_rating_notification(self, change_rating_notification: NotificationSetting) -> Namespace:
+        self.change_rating_notification = change_rating_notification
+        return self
+
     def with_log_setting(self, log_setting: LogSetting) -> Namespace:
         self.log_setting = log_setting
         return self
@@ -1616,6 +1635,7 @@ class Namespace(core.Gs2Model):
             .with_join_notification(NotificationSetting.from_dict(data.get('joinNotification')))\
             .with_leave_notification(NotificationSetting.from_dict(data.get('leaveNotification')))\
             .with_complete_notification(NotificationSetting.from_dict(data.get('completeNotification')))\
+            .with_change_rating_notification(NotificationSetting.from_dict(data.get('changeRatingNotification')))\
             .with_log_setting(LogSetting.from_dict(data.get('logSetting')))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))
@@ -1636,6 +1656,7 @@ class Namespace(core.Gs2Model):
             "joinNotification": self.join_notification.to_dict() if self.join_notification else None,
             "leaveNotification": self.leave_notification.to_dict() if self.leave_notification else None,
             "completeNotification": self.complete_notification.to_dict() if self.complete_notification else None,
+            "changeRatingNotification": self.change_rating_notification.to_dict() if self.change_rating_notification else None,
             "logSetting": self.log_setting.to_dict() if self.log_setting else None,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
