@@ -135,6 +135,8 @@ class Gs2MatchmakingRestClient(rest.AbstractGs2RestClient):
             body["leaveNotification"] = request.leave_notification.to_dict()
         if request.complete_notification is not None:
             body["completeNotification"] = request.complete_notification.to_dict()
+        if request.change_rating_notification is not None:
+            body["changeRatingNotification"] = request.change_rating_notification.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -374,6 +376,8 @@ class Gs2MatchmakingRestClient(rest.AbstractGs2RestClient):
             body["leaveNotification"] = request.leave_notification.to_dict()
         if request.complete_notification is not None:
             body["completeNotification"] = request.complete_notification.to_dict()
+        if request.change_rating_notification is not None:
+            body["changeRatingNotification"] = request.change_rating_notification.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -1553,6 +1557,8 @@ class Gs2MatchmakingRestClient(rest.AbstractGs2RestClient):
             body["description"] = request.description
         if request.metadata is not None:
             body["metadata"] = request.metadata
+        if request.initial_value is not None:
+            body["initialValue"] = request.initial_value
         if request.volatility is not None:
             body["volatility"] = request.volatility
 
@@ -1703,6 +1709,8 @@ class Gs2MatchmakingRestClient(rest.AbstractGs2RestClient):
             body["description"] = request.description
         if request.metadata is not None:
             body["metadata"] = request.metadata
+        if request.initial_value is not None:
+            body["initialValue"] = request.initial_value
         if request.volatility is not None:
             body["volatility"] = request.volatility
 
