@@ -137,6 +137,8 @@ class Gs2MatchmakingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["leaveNotification"] = request.leave_notification.to_dict()
         if request.complete_notification is not None:
             body["completeNotification"] = request.complete_notification.to_dict()
+        if request.change_rating_notification is not None:
+            body["changeRatingNotification"] = request.change_rating_notification.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -376,6 +378,8 @@ class Gs2MatchmakingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["leaveNotification"] = request.leave_notification.to_dict()
         if request.complete_notification is not None:
             body["completeNotification"] = request.complete_notification.to_dict()
+        if request.change_rating_notification is not None:
+            body["changeRatingNotification"] = request.change_rating_notification.to_dict()
         if request.log_setting is not None:
             body["logSetting"] = request.log_setting.to_dict()
 
@@ -1573,6 +1577,8 @@ class Gs2MatchmakingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["description"] = request.description
         if request.metadata is not None:
             body["metadata"] = request.metadata
+        if request.initial_value is not None:
+            body["initialValue"] = request.initial_value
         if request.volatility is not None:
             body["volatility"] = request.volatility
 
@@ -1725,6 +1731,8 @@ class Gs2MatchmakingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["description"] = request.description
         if request.metadata is not None:
             body["metadata"] = request.metadata
+        if request.initial_value is not None:
+            body["initialValue"] = request.initial_value
         if request.volatility is not None:
             body["volatility"] = request.volatility
 
