@@ -1143,7 +1143,7 @@ class PutPositionRequest(core.Gs2Request):
     position: Position = None
     vector: Vector = None
     r: float = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> PutPositionRequest:
         self.namespace_name = namespace_name
@@ -1173,6 +1173,10 @@ class PutPositionRequest(core.Gs2Request):
         self.r = r
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> PutPositionRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1303,7 +1307,7 @@ class FetchPositionRequest(core.Gs2Request):
     area_model_name: str = None
     layer_model_name: str = None
     user_ids: List[str] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> FetchPositionRequest:
         self.namespace_name = namespace_name
@@ -1325,6 +1329,10 @@ class FetchPositionRequest(core.Gs2Request):
         self.user_ids = user_ids
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> FetchPositionRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1444,7 +1452,7 @@ class NearUserIdsRequest(core.Gs2Request):
     point: Position = None
     r: float = None
     limit: int = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> NearUserIdsRequest:
         self.namespace_name = namespace_name
@@ -1474,6 +1482,10 @@ class NearUserIdsRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> NearUserIdsRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1598,7 +1610,7 @@ class ActionRequest(core.Gs2Request):
     layer_model_name: str = None
     position: MyPosition = None
     scopes: List[Scope] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> ActionRequest:
         self.namespace_name = namespace_name
@@ -1624,6 +1636,10 @@ class ActionRequest(core.Gs2Request):
         self.scopes = scopes
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> ActionRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
