@@ -130,10 +130,15 @@ class GitHubCheckoutSetting(core.Gs2Model):
 
 
 class SubscribeUser(core.Gs2Model):
+    subscribe_user_id: str = None
     category_name: str = None
     user_id: str = None
     target_user_id: str = None
 
+    def with_subscribe_user_id(self, subscribe_user_id: str) -> SubscribeUser:
+        self.subscribe_user_id = subscribe_user_id
+        return self
+
     def with_category_name(self, category_name: str) -> SubscribeUser:
         self.category_name = category_name
         return self
@@ -146,6 +151,85 @@ class SubscribeUser(core.Gs2Model):
         self.target_user_id = target_user_id
         return self
 
+    @classmethod
+    def create_grn(
+        cls,
+        region,
+        owner_id,
+        namespace_name,
+        user_id,
+        category_name,
+        target_user_id,
+    ):
+        return 'grn:gs2:{region}:{ownerId}:ranking:{namespaceName}:user:{userId}:subscribe:category:{categoryName}:{targetUserId}'.format(
+            region=region,
+            ownerId=owner_id,
+            namespaceName=namespace_name,
+            userId=user_id,
+            categoryName=category_name,
+            targetUserId=target_user_id,
+        )
+
+    @classmethod
+    def get_region_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):ranking:(?P<namespaceName>.+):user:(?P<userId>.+):subscribe:category:(?P<categoryName>.+):(?P<targetUserId>.+)', grn)
+        if match is None:
+            return None
+        return match.group('region')
+
+    @classmethod
+    def get_owner_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):ranking:(?P<namespaceName>.+):user:(?P<userId>.+):subscribe:category:(?P<categoryName>.+):(?P<targetUserId>.+)', grn)
+        if match is None:
+            return None
+        return match.group('owner_id')
+
+    @classmethod
+    def get_namespace_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):ranking:(?P<namespaceName>.+):user:(?P<userId>.+):subscribe:category:(?P<categoryName>.+):(?P<targetUserId>.+)', grn)
+        if match is None:
+            return None
+        return match.group('namespace_name')
+
+    @classmethod
+    def get_user_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):ranking:(?P<namespaceName>.+):user:(?P<userId>.+):subscribe:category:(?P<categoryName>.+):(?P<targetUserId>.+)', grn)
+        if match is None:
+            return None
+        return match.group('user_id')
+
+    @classmethod
+    def get_category_name_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):ranking:(?P<namespaceName>.+):user:(?P<userId>.+):subscribe:category:(?P<categoryName>.+):(?P<targetUserId>.+)', grn)
+        if match is None:
+            return None
+        return match.group('category_name')
+
+    @classmethod
+    def get_target_user_id_from_grn(
+        cls,
+        grn: str,
+    ) -> Optional[str]:
+        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):ranking:(?P<namespaceName>.+):user:(?P<userId>.+):subscribe:category:(?P<categoryName>.+):(?P<targetUserId>.+)', grn)
+        if match is None:
+            return None
+        return match.group('target_user_id')
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -165,12 +249,14 @@ class SubscribeUser(core.Gs2Model):
         if data is None:
             return None
         return SubscribeUser()\
+            .with_subscribe_user_id(data.get('subscribeUserId'))\
             .with_category_name(data.get('categoryName'))\
             .with_user_id(data.get('userId'))\
             .with_target_user_id(data.get('targetUserId'))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
+            "subscribeUserId": self.subscribe_user_id,
             "categoryName": self.category_name,
             "userId": self.user_id,
             "targetUserId": self.target_user_id,
@@ -710,11 +796,13 @@ class CategoryModelMaster(core.Gs2Model):
     order_direction: str = None
     scope: str = None
     unique_by_user_id: bool = None
+    sum: bool = None
     calculate_fixed_timing_hour: int = None
     calculate_fixed_timing_minute: int = None
     calculate_interval_minutes: int = None
     entry_period_event_id: str = None
     access_period_event_id: str = None
+    ignore_user_ids: List[str] = None
     generation: str = None
     created_at: int = None
     updated_at: int = None
@@ -755,6 +843,10 @@ class CategoryModelMaster(core.Gs2Model):
         self.unique_by_user_id = unique_by_user_id
         return self
 
+    def with_sum(self, sum: bool) -> CategoryModelMaster:
+        self.sum = sum
+        return self
+
     def with_calculate_fixed_timing_hour(self, calculate_fixed_timing_hour: int) -> CategoryModelMaster:
         self.calculate_fixed_timing_hour = calculate_fixed_timing_hour
         return self
@@ -775,6 +867,10 @@ class CategoryModelMaster(core.Gs2Model):
         self.access_period_event_id = access_period_event_id
         return self
 
+    def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> CategoryModelMaster:
+        self.ignore_user_ids = ignore_user_ids
+        return self
+
     def with_generation(self, generation: str) -> CategoryModelMaster:
         self.generation = generation
         return self
@@ -870,11 +966,16 @@ class CategoryModelMaster(core.Gs2Model):
             .with_order_direction(data.get('orderDirection'))\
             .with_scope(data.get('scope'))\
             .with_unique_by_user_id(data.get('uniqueByUserId'))\
+            .with_sum(data.get('sum'))\
             .with_calculate_fixed_timing_hour(data.get('calculateFixedTimingHour'))\
             .with_calculate_fixed_timing_minute(data.get('calculateFixedTimingMinute'))\
             .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
             .with_entry_period_event_id(data.get('entryPeriodEventId'))\
             .with_access_period_event_id(data.get('accessPeriodEventId'))\
+            .with_ignore_user_ids([
+                data.get('ignoreUserIds')[i]
+                for i in range(len(data.get('ignoreUserIds')) if data.get('ignoreUserIds') else 0)
+            ])\
             .with_generation(data.get('generation'))\
             .with_created_at(data.get('createdAt'))\
             .with_updated_at(data.get('updatedAt'))
@@ -890,11 +991,16 @@ class CategoryModelMaster(core.Gs2Model):
             "orderDirection": self.order_direction,
             "scope": self.scope,
             "uniqueByUserId": self.unique_by_user_id,
+            "sum": self.sum,
             "calculateFixedTimingHour": self.calculate_fixed_timing_hour,
             "calculateFixedTimingMinute": self.calculate_fixed_timing_minute,
             "calculateIntervalMinutes": self.calculate_interval_minutes,
             "entryPeriodEventId": self.entry_period_event_id,
             "accessPeriodEventId": self.access_period_event_id,
+            "ignoreUserIds": [
+                self.ignore_user_ids[i]
+                for i in range(len(self.ignore_user_ids) if self.ignore_user_ids else 0)
+            ],
             "generation": self.generation,
             "createdAt": self.created_at,
             "updatedAt": self.updated_at,
@@ -910,11 +1016,13 @@ class CategoryModel(core.Gs2Model):
     order_direction: str = None
     scope: str = None
     unique_by_user_id: bool = None
+    sum: bool = None
     calculate_fixed_timing_hour: int = None
     calculate_fixed_timing_minute: int = None
     calculate_interval_minutes: int = None
     entry_period_event_id: str = None
     access_period_event_id: str = None
+    ignore_user_ids: List[str] = None
     generation: str = None
 
     def with_category_model_id(self, category_model_id: str) -> CategoryModel:
@@ -949,6 +1057,10 @@ class CategoryModel(core.Gs2Model):
         self.unique_by_user_id = unique_by_user_id
         return self
 
+    def with_sum(self, sum: bool) -> CategoryModel:
+        self.sum = sum
+        return self
+
     def with_calculate_fixed_timing_hour(self, calculate_fixed_timing_hour: int) -> CategoryModel:
         self.calculate_fixed_timing_hour = calculate_fixed_timing_hour
         return self
@@ -969,6 +1081,10 @@ class CategoryModel(core.Gs2Model):
         self.access_period_event_id = access_period_event_id
         return self
 
+    def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> CategoryModel:
+        self.ignore_user_ids = ignore_user_ids
+        return self
+
     def with_generation(self, generation: str) -> CategoryModel:
         self.generation = generation
         return self
@@ -1055,11 +1171,16 @@ class CategoryModel(core.Gs2Model):
             .with_order_direction(data.get('orderDirection'))\
             .with_scope(data.get('scope'))\
             .with_unique_by_user_id(data.get('uniqueByUserId'))\
+            .with_sum(data.get('sum'))\
             .with_calculate_fixed_timing_hour(data.get('calculateFixedTimingHour'))\
             .with_calculate_fixed_timing_minute(data.get('calculateFixedTimingMinute'))\
             .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
             .with_entry_period_event_id(data.get('entryPeriodEventId'))\
             .with_access_period_event_id(data.get('accessPeriodEventId'))\
+            .with_ignore_user_ids([
+                data.get('ignoreUserIds')[i]
+                for i in range(len(data.get('ignoreUserIds')) if data.get('ignoreUserIds') else 0)
+            ])\
             .with_generation(data.get('generation'))
 
     def to_dict(self) -> Dict[str, Any]:
@@ -1072,11 +1193,16 @@ class CategoryModel(core.Gs2Model):
             "orderDirection": self.order_direction,
             "scope": self.scope,
             "uniqueByUserId": self.unique_by_user_id,
+            "sum": self.sum,
             "calculateFixedTimingHour": self.calculate_fixed_timing_hour,
             "calculateFixedTimingMinute": self.calculate_fixed_timing_minute,
             "calculateIntervalMinutes": self.calculate_interval_minutes,
             "entryPeriodEventId": self.entry_period_event_id,
             "accessPeriodEventId": self.access_period_event_id,
+            "ignoreUserIds": [
+                self.ignore_user_ids[i]
+                for i in range(len(self.ignore_user_ids) if self.ignore_user_ids else 0)
+            ],
             "generation": self.generation,
         }
 
