@@ -409,11 +409,13 @@ class CreateCategoryModelMasterRequest(core.Gs2Request):
     order_direction: str = None
     scope: str = None
     unique_by_user_id: bool = None
+    sum: bool = None
     calculate_fixed_timing_hour: int = None
     calculate_fixed_timing_minute: int = None
     calculate_interval_minutes: int = None
     entry_period_event_id: str = None
     access_period_event_id: str = None
+    ignore_user_ids: List[str] = None
     generation: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateCategoryModelMasterRequest:
@@ -452,6 +454,10 @@ class CreateCategoryModelMasterRequest(core.Gs2Request):
         self.unique_by_user_id = unique_by_user_id
         return self
 
+    def with_sum(self, sum: bool) -> CreateCategoryModelMasterRequest:
+        self.sum = sum
+        return self
+
     def with_calculate_fixed_timing_hour(self, calculate_fixed_timing_hour: int) -> CreateCategoryModelMasterRequest:
         self.calculate_fixed_timing_hour = calculate_fixed_timing_hour
         return self
@@ -472,6 +478,10 @@ class CreateCategoryModelMasterRequest(core.Gs2Request):
         self.access_period_event_id = access_period_event_id
         return self
 
+    def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> CreateCategoryModelMasterRequest:
+        self.ignore_user_ids = ignore_user_ids
+        return self
+
     def with_generation(self, generation: str) -> CreateCategoryModelMasterRequest:
         self.generation = generation
         return self
@@ -504,11 +514,16 @@ class CreateCategoryModelMasterRequest(core.Gs2Request):
             .with_order_direction(data.get('orderDirection'))\
             .with_scope(data.get('scope'))\
             .with_unique_by_user_id(data.get('uniqueByUserId'))\
+            .with_sum(data.get('sum'))\
             .with_calculate_fixed_timing_hour(data.get('calculateFixedTimingHour'))\
             .with_calculate_fixed_timing_minute(data.get('calculateFixedTimingMinute'))\
             .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
             .with_entry_period_event_id(data.get('entryPeriodEventId'))\
             .with_access_period_event_id(data.get('accessPeriodEventId'))\
+            .with_ignore_user_ids([
+                data.get('ignoreUserIds')[i]
+                for i in range(len(data.get('ignoreUserIds')) if data.get('ignoreUserIds') else 0)
+            ])\
             .with_generation(data.get('generation'))
 
     def to_dict(self) -> Dict[str, Any]:
@@ -522,11 +537,16 @@ class CreateCategoryModelMasterRequest(core.Gs2Request):
             "orderDirection": self.order_direction,
             "scope": self.scope,
             "uniqueByUserId": self.unique_by_user_id,
+            "sum": self.sum,
             "calculateFixedTimingHour": self.calculate_fixed_timing_hour,
             "calculateFixedTimingMinute": self.calculate_fixed_timing_minute,
             "calculateIntervalMinutes": self.calculate_interval_minutes,
             "entryPeriodEventId": self.entry_period_event_id,
             "accessPeriodEventId": self.access_period_event_id,
+            "ignoreUserIds": [
+                self.ignore_user_ids[i]
+                for i in range(len(self.ignore_user_ids) if self.ignore_user_ids else 0)
+            ],
             "generation": self.generation,
         }
 
@@ -586,11 +606,13 @@ class UpdateCategoryModelMasterRequest(core.Gs2Request):
     order_direction: str = None
     scope: str = None
     unique_by_user_id: bool = None
+    sum: bool = None
     calculate_fixed_timing_hour: int = None
     calculate_fixed_timing_minute: int = None
     calculate_interval_minutes: int = None
     entry_period_event_id: str = None
     access_period_event_id: str = None
+    ignore_user_ids: List[str] = None
     generation: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateCategoryModelMasterRequest:
@@ -629,6 +651,10 @@ class UpdateCategoryModelMasterRequest(core.Gs2Request):
         self.unique_by_user_id = unique_by_user_id
         return self
 
+    def with_sum(self, sum: bool) -> UpdateCategoryModelMasterRequest:
+        self.sum = sum
+        return self
+
     def with_calculate_fixed_timing_hour(self, calculate_fixed_timing_hour: int) -> UpdateCategoryModelMasterRequest:
         self.calculate_fixed_timing_hour = calculate_fixed_timing_hour
         return self
@@ -649,6 +675,10 @@ class UpdateCategoryModelMasterRequest(core.Gs2Request):
         self.access_period_event_id = access_period_event_id
         return self
 
+    def with_ignore_user_ids(self, ignore_user_ids: List[str]) -> UpdateCategoryModelMasterRequest:
+        self.ignore_user_ids = ignore_user_ids
+        return self
+
     def with_generation(self, generation: str) -> UpdateCategoryModelMasterRequest:
         self.generation = generation
         return self
@@ -681,11 +711,16 @@ class UpdateCategoryModelMasterRequest(core.Gs2Request):
             .with_order_direction(data.get('orderDirection'))\
             .with_scope(data.get('scope'))\
             .with_unique_by_user_id(data.get('uniqueByUserId'))\
+            .with_sum(data.get('sum'))\
             .with_calculate_fixed_timing_hour(data.get('calculateFixedTimingHour'))\
             .with_calculate_fixed_timing_minute(data.get('calculateFixedTimingMinute'))\
             .with_calculate_interval_minutes(data.get('calculateIntervalMinutes'))\
             .with_entry_period_event_id(data.get('entryPeriodEventId'))\
             .with_access_period_event_id(data.get('accessPeriodEventId'))\
+            .with_ignore_user_ids([
+                data.get('ignoreUserIds')[i]
+                for i in range(len(data.get('ignoreUserIds')) if data.get('ignoreUserIds') else 0)
+            ])\
             .with_generation(data.get('generation'))
 
     def to_dict(self) -> Dict[str, Any]:
@@ -699,11 +734,16 @@ class UpdateCategoryModelMasterRequest(core.Gs2Request):
             "orderDirection": self.order_direction,
             "scope": self.scope,
             "uniqueByUserId": self.unique_by_user_id,
+            "sum": self.sum,
             "calculateFixedTimingHour": self.calculate_fixed_timing_hour,
             "calculateFixedTimingMinute": self.calculate_fixed_timing_minute,
             "calculateIntervalMinutes": self.calculate_interval_minutes,
             "entryPeriodEventId": self.entry_period_event_id,
             "accessPeriodEventId": self.access_period_event_id,
+            "ignoreUserIds": [
+                self.ignore_user_ids[i]
+                for i in range(len(self.ignore_user_ids) if self.ignore_user_ids else 0)
+            ],
             "generation": self.generation,
         }
 
