@@ -708,6 +708,8 @@ class Gs2RankingRestClient(rest.AbstractGs2RestClient):
             body["scope"] = request.scope
         if request.unique_by_user_id is not None:
             body["uniqueByUserId"] = request.unique_by_user_id
+        if request.sum is not None:
+            body["sum"] = request.sum
         if request.calculate_fixed_timing_hour is not None:
             body["calculateFixedTimingHour"] = request.calculate_fixed_timing_hour
         if request.calculate_fixed_timing_minute is not None:
@@ -718,6 +720,11 @@ class Gs2RankingRestClient(rest.AbstractGs2RestClient):
             body["entryPeriodEventId"] = request.entry_period_event_id
         if request.access_period_event_id is not None:
             body["accessPeriodEventId"] = request.access_period_event_id
+        if request.ignore_user_ids is not None:
+            body["ignoreUserIds"] = [
+                item
+                for item in request.ignore_user_ids
+            ]
         if request.generation is not None:
             body["generation"] = request.generation
 
@@ -878,6 +885,8 @@ class Gs2RankingRestClient(rest.AbstractGs2RestClient):
             body["scope"] = request.scope
         if request.unique_by_user_id is not None:
             body["uniqueByUserId"] = request.unique_by_user_id
+        if request.sum is not None:
+            body["sum"] = request.sum
         if request.calculate_fixed_timing_hour is not None:
             body["calculateFixedTimingHour"] = request.calculate_fixed_timing_hour
         if request.calculate_fixed_timing_minute is not None:
@@ -888,6 +897,11 @@ class Gs2RankingRestClient(rest.AbstractGs2RestClient):
             body["entryPeriodEventId"] = request.entry_period_event_id
         if request.access_period_event_id is not None:
             body["accessPeriodEventId"] = request.access_period_event_id
+        if request.ignore_user_ids is not None:
+            body["ignoreUserIds"] = [
+                item
+                for item in request.ignore_user_ids
+            ]
         if request.generation is not None:
             body["generation"] = request.generation
 
