@@ -711,6 +711,8 @@ class Gs2RankingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["scope"] = request.scope
         if request.unique_by_user_id is not None:
             body["uniqueByUserId"] = request.unique_by_user_id
+        if request.sum is not None:
+            body["sum"] = request.sum
         if request.calculate_fixed_timing_hour is not None:
             body["calculateFixedTimingHour"] = request.calculate_fixed_timing_hour
         if request.calculate_fixed_timing_minute is not None:
@@ -721,6 +723,11 @@ class Gs2RankingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["entryPeriodEventId"] = request.entry_period_event_id
         if request.access_period_event_id is not None:
             body["accessPeriodEventId"] = request.access_period_event_id
+        if request.ignore_user_ids is not None:
+            body["ignoreUserIds"] = [
+                item
+                for item in request.ignore_user_ids
+            ]
         if request.generation is not None:
             body["generation"] = request.generation
 
@@ -883,6 +890,8 @@ class Gs2RankingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["scope"] = request.scope
         if request.unique_by_user_id is not None:
             body["uniqueByUserId"] = request.unique_by_user_id
+        if request.sum is not None:
+            body["sum"] = request.sum
         if request.calculate_fixed_timing_hour is not None:
             body["calculateFixedTimingHour"] = request.calculate_fixed_timing_hour
         if request.calculate_fixed_timing_minute is not None:
@@ -893,6 +902,11 @@ class Gs2RankingWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body["entryPeriodEventId"] = request.entry_period_event_id
         if request.access_period_event_id is not None:
             body["accessPeriodEventId"] = request.access_period_event_id
+        if request.ignore_user_ids is not None:
+            body["ignoreUserIds"] = [
+                item
+                for item in request.ignore_user_ids
+            ]
         if request.generation is not None:
             body["generation"] = request.generation
 
