@@ -803,11 +803,31 @@ class DescribeRawEventsResult(core.Gs2Result):
 
 class GetEventResult(core.Gs2Result):
     item: Event = None
+    in_schedule: bool = None
+    schedule_start_at: int = None
+    schedule_end_at: int = None
+    repeat_schedule: RepeatSchedule = None
 
     def with_item(self, item: Event) -> GetEventResult:
         self.item = item
         return self
 
+    def with_in_schedule(self, in_schedule: bool) -> GetEventResult:
+        self.in_schedule = in_schedule
+        return self
+
+    def with_schedule_start_at(self, schedule_start_at: int) -> GetEventResult:
+        self.schedule_start_at = schedule_start_at
+        return self
+
+    def with_schedule_end_at(self, schedule_end_at: int) -> GetEventResult:
+        self.schedule_end_at = schedule_end_at
+        return self
+
+    def with_repeat_schedule(self, repeat_schedule: RepeatSchedule) -> GetEventResult:
+        self.repeat_schedule = repeat_schedule
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -827,21 +847,49 @@ class GetEventResult(core.Gs2Result):
         if data is None:
             return None
         return GetEventResult()\
-            .with_item(Event.from_dict(data.get('item')))
+            .with_item(Event.from_dict(data.get('item')))\
+            .with_in_schedule(data.get('inSchedule'))\
+            .with_schedule_start_at(data.get('scheduleStartAt'))\
+            .with_schedule_end_at(data.get('scheduleEndAt'))\
+            .with_repeat_schedule(RepeatSchedule.from_dict(data.get('repeatSchedule')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "item": self.item.to_dict() if self.item else None,
+            "inSchedule": self.in_schedule,
+            "scheduleStartAt": self.schedule_start_at,
+            "scheduleEndAt": self.schedule_end_at,
+            "repeatSchedule": self.repeat_schedule.to_dict() if self.repeat_schedule else None,
         }
 
 
 class GetEventByUserIdResult(core.Gs2Result):
     item: Event = None
+    in_schedule: bool = None
+    schedule_start_at: int = None
+    schedule_end_at: int = None
+    repeat_schedule: RepeatSchedule = None
 
     def with_item(self, item: Event) -> GetEventByUserIdResult:
         self.item = item
         return self
 
+    def with_in_schedule(self, in_schedule: bool) -> GetEventByUserIdResult:
+        self.in_schedule = in_schedule
+        return self
+
+    def with_schedule_start_at(self, schedule_start_at: int) -> GetEventByUserIdResult:
+        self.schedule_start_at = schedule_start_at
+        return self
+
+    def with_schedule_end_at(self, schedule_end_at: int) -> GetEventByUserIdResult:
+        self.schedule_end_at = schedule_end_at
+        return self
+
+    def with_repeat_schedule(self, repeat_schedule: RepeatSchedule) -> GetEventByUserIdResult:
+        self.repeat_schedule = repeat_schedule
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -861,11 +909,19 @@ class GetEventByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return GetEventByUserIdResult()\
-            .with_item(Event.from_dict(data.get('item')))
+            .with_item(Event.from_dict(data.get('item')))\
+            .with_in_schedule(data.get('inSchedule'))\
+            .with_schedule_start_at(data.get('scheduleStartAt'))\
+            .with_schedule_end_at(data.get('scheduleEndAt'))\
+            .with_repeat_schedule(RepeatSchedule.from_dict(data.get('repeatSchedule')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "item": self.item.to_dict() if self.item else None,
+            "inSchedule": self.in_schedule,
+            "scheduleStartAt": self.schedule_start_at,
+            "scheduleEndAt": self.schedule_end_at,
+            "repeatSchedule": self.repeat_schedule.to_dict() if self.repeat_schedule else None,
         }
 
 
