@@ -1005,6 +1005,8 @@ class Gs2ScriptWebSocketClient(web_socket.AbstractGs2WebSocketClient):
             body['contextStack'] = str(request.context_stack)
         if request.script_id is not None:
             body["scriptId"] = request.script_id
+        if request.user_id is not None:
+            body["userId"] = request.user_id
         if request.args is not None:
             body["args"] = request.args
 
